# organage

A package to pestimate organ-specific biological age using SomaScan plasma proteomics data

## Installation

```bash
$ pip install organage
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`organage` was created by Hamilton Oh. It is licensed under the terms of the MIT license.

## Credits

`organage` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
